@@ -1,3 +1,26 @@
+##############################################################################
+#    Copyright (c) 2012-2016 Russell V. Lenth                                #
+#                                                                            #
+#    This file is part of the lsmeans package for R (*lsmeans*)              #
+#                                                                            #
+#    *lsmeans* is free software: you can redistribute it and/or modify       #
+#    it under the terms of the GNU General Public License as published by    #
+#    the Free Software Foundation, either version 2 of the License, or       #
+#    (at your option) any later version.                                     #
+#                                                                            #
+#    *lsmeans* is distributed in the hope that it will be useful,            #
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of          #
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
+#    GNU General Public License for more details.                            #
+#                                                                            #
+#    You should have received a copy of the GNU General Public License       #
+#    along with R and *lsmeans*.  If not, see                                #
+#    <https://www.r-project.org/Licenses/> and/or                            #
+#    <http://www.gnu.org/licenses/>.                                         #
+##############################################################################
+
+# lsmeans and related functions
+
 # Utility to pick out the args that can be passed to a function
 .args.for.fcn = function(fcn, args) {
     oknames = names(as.list(args(fcn)))
@@ -137,9 +160,15 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
     RG = object
     facs = union(specs, by)
     
+    if ((length(facs) == 1) && (facs == "1")) {  ### just want grand mean
+        RG@levels[["1"]] = "overall"
+        RG@grid[ ,"1"] = 1
+    }
+    
+    
     # Figure out the structure of the grid
     wgt = RG@grid[[".wgt."]]
-    if(all(zapsmall(wgt) == 0)) wgt = wgt + 1 ### repl all zero wgts with 1
+    if(!is.null(wgt) && all(zapsmall(wgt) == 0)) wgt = wgt + 1 ### repl all zero wgts with 1
     dims = sapply(RG@levels, length)
     row.idx = array(seq_len(nrow(RG@linfct)), dims)
     use.mars = match(facs, names(RG@levels)) # which margins to use
@@ -149,7 +178,7 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
     if ((length(avgd.mars) > 0) && !missing(weights)) {
         if (is.character(weights)) {
             if (is.null(wgt))
-                message("Weighting information not available -- deferring to fac.reduce")
+                warning("'weights' requested but no weighting information is available")
             else {
                 wopts = c("equal","proportional","outer","cells","show.levels","invalid")
                 weights = switch(wopts[pmatch(weights, wopts, 5)],
@@ -251,17 +280,21 @@ lsmeans.character.ref.grid = function(object, specs, by = NULL,
         result = do.call("update.ref.grid", options)
     }
     
-    if (missing(contr))
-        result
+    # if (missing(contr))
+    #     result
     
-    else { # return a list with lsmeans and contrasts
+    if(!missing(contr)) { # return a list with lsmeans and contrasts
         if (is.character(contr) && contr == "cld") {
         # TO DO: provide for passing dots to cld                
             return(cld(result, by = by))
         }
         ctrs = contrast(result, method = contr, by = by, ...)
-        .cls.list("lsm.list", lsmeans = result, contrasts = ctrs)
+        result = .cls.list("lsm.list", lsmeans = result, contrasts = ctrs)
+        if(!is.null(lbl <- object@misc$methDesc))
+            names(result)[1] = lbl
     }
+    
+    result
 }
 
 
@@ -286,6 +319,9 @@ contrast.ref.grid = function(object, method = "eff", interaction = FALSE,
         by = object@misc$by.vars
     if(length(by) == 0) # character(0) --> NULL
         by = NULL
+    
+    orig.grid = object@grid
+    orig.grid[[".wgt."]] = orig.grid[[".offset."]] = NULL
 
     if (is.logical(interaction) && interaction)
         interaction = method
@@ -302,12 +338,19 @@ contrast.ref.grid = function(object, method = "eff", interaction = FALSE,
             k = k - length(by)
         }
         interaction = rep(interaction, k)[1:k]
+        tcm = NULL
         for (i in k:1) {
             nm = paste(vars[i], interaction[i], sep = "_")
             object = contrast.ref.grid(object, interaction[i], by = vars[-i], name = nm)
+            if(is.null(tcm))
+                tcm = object@misc$con.coef
+            else
+                tcm = object@misc$con.coef %*% tcm
             vars[i] = nm
         }
         object = update(object, by = by, adjust = adjust, ...)
+        object@misc$orig.grid = orig.grid
+        object@misc$con.coef = tcm
         if(!is.null(options)) {
             options$object = object
             object = do.call(update.ref.grid, options)
@@ -348,6 +391,7 @@ contrast.ref.grid = function(object, method = "eff", interaction = FALSE,
     
     # Get the contrasts; this should be a data.frame
     cmat = method(levs, ...)
+    tcmat = t(cmat)
     if (!is.data.frame(cmat))
         stop("Contrast function must provide a data.frame")
     else if(ncol(cmat) == 0)
@@ -357,10 +401,11 @@ contrast.ref.grid = function(object, method = "eff", interaction = FALSE,
         stop("Nonconforming number of contrast coefficients")
     
     if (is.null(by)) {
-        linfct = t(cmat) %*% object@linfct
+        linfct = tcmat %*% object@linfct
         grid = data.frame(.contrast.=names(cmat))
         if (hasName(object@grid, ".offset."))
             grid[[".offset."]] = t(cmat) %*% object@grid[[".offset."]]
+        by.rows = list(seq_along(object@linfct[ , 1]))
     }
     
     # NOTE: The kronecker thing here is nice and efficient but depends
@@ -368,9 +413,9 @@ contrast.ref.grid = function(object, method = "eff", interaction = FALSE,
     # If you ever want to expand to irregular grids, this block will
     # have to change, but everything else is probably OK.
     else {
-        tcmat = kronecker(.diag(rep(1,length(by.rows))), t(cmat))
-        linfct = tcmat %*% object@linfct[unlist(by.rows), ]
-        tmp = expand.grid(con= names(cmat), by = seq_len(length(by.rows)))###unique(by.id))
+        tcmat = kronecker(.diag(rep(1,length(by.rows))), tcmat)
+        linfct = tcmat %*% object@linfct[unlist(by.rows), , drop = FALSE]
+        tmp = expand.grid(con = names(cmat), by = seq_len(length(by.rows)))###unique(by.id))
         grid = data.frame(.contrast. = tmp$con)
         n.each = ncol(cmat)
         row.1st = sapply(by.rows, function(x) x[1])
@@ -416,6 +461,12 @@ contrast.ref.grid = function(object, method = "eff", interaction = FALSE,
     misc$adjust = adjust
     misc$infer = c(FALSE, TRUE)
     misc$by.vars = by
+    # save contrast coefs
+    by.cols = seq_len(ncol(tcmat))
+    if(!is.null(by.rows))
+        by.cols[unlist(by.rows)] = by.cols # gives us inverse of by.rows order
+    misc$orig.grid = orig.grid  # save original grid
+    misc$con.coef = tcmat[ , by.cols, drop = FALSE] # save contrast coefs
     # zap the transformation info except in very special cases
     if (!is.null(misc$tran)) {
         misc$orig.tran = misc$tran
@@ -581,6 +632,19 @@ pairs.ref.grid = function(x, reverse = FALSE, ...) {
 }
 
 
+# coef method - returns contrast coefficients, or identity matrix if no contrasts
+coef.ref.grid = function(object, ...) {
+    if (is.null(cc <- object@misc$con.coef)) {
+        message("No contrast coefficients are available")
+        return (NULL)
+    }
+    cc = as.data.frame(t(cc))
+    names(cc) = paste("c", seq_len(ncol(cc)), sep = ".")
+    cbind(object@misc$orig.grid, cc)
+}
+    
+
+
 
 
 # Check if model contains a term containing all elts of facs
